/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.kenai.com
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.examples.nodes.example8.view;

import javax.annotation.concurrent.ThreadSafe;
import javax.annotation.Nonnull;
import java.util.Comparator;
import it.tidalwave.util.DefaultFilterSortCriterion;
import it.tidalwave.util.Finder.SortCriterion;
import static it.tidalwave.netbeans.util.EnhancedLookups.*;
import static it.tidalwave.netbeans.examples.nodes.example8.role.SizedInBytes.SizedInBytes;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 * @draft
 *
 **********************************************************************************************************************/
@ThreadSafe
public final class CompareBySizedInBytes extends DefaultFilterSortCriterion<Object> 
  {
    public static final SortCriterion BY_SIZE_IN_BYTES = new CompareBySizedInBytes();
    
    private CompareBySizedInBytes() 
      {
        super(new Comparator<Object>()
          {
            @Override
            public int compare (final @Nonnull Object o1, final @Nonnull Object o2)
              {
                final long s1 = lookup(o1, SizedInBytes).getByteCount();
                final long s2 = lookup(o2, SizedInBytes).getByteCount();
                return (s1 == s2) ? 0 : (s1 > s2) ? + 1 : -1; // just computing the difference may overflow int
              }
          });
      }
  }
