/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.kenai.com
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.examples.nodes.example8.view;

import javax.annotation.Nonnull;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;
import javax.swing.Action;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.util.Finder.SortDirection;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import it.tidalwave.netbeans.nodes.LookupFilterDecoratorNode;
import it.tidalwave.netbeans.nodes.LookupFilterDecoratorNode.LookupFilter;
import it.tidalwave.netbeans.nodes.role.NodeDecorator;
import it.tidalwave.netbeans.nodes.role.ActionProvider;
import static it.tidalwave.netbeans.util.EnhancedLookups.*;
import static it.tidalwave.netbeans.examples.nodes.example8.view.CompareByDisplayName.*;
import static it.tidalwave.netbeans.examples.nodes.example8.view.CompareByDisplayNameIgnoringCase.*;
import static it.tidalwave.netbeans.examples.nodes.example8.view.CompareBySizedInBytes.*;

/***********************************************************************************************************************
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class SortActionsNodeDecorator implements NodeDecorator
  {
    private static class SortActionProvider implements ActionProvider
      {
        private final List<Action> actions = new ArrayList<Action>();    

        public SortActionProvider (final @Nonnull Object object) 
          {
            actions.add(new SortCriterionAction(object, "Sort by name",               BY_DISPLAY_NAME));
            actions.add(new SortCriterionAction(object, "Sort by name (ignore case)", BY_DISPLAY_NAME_IGNORING_CASE));
            actions.add(new SortCriterionAction(object, "Sort by size",               BY_SIZE_IN_BYTES));
            actions.add(new SortDirectionAction(object, "Sort in ascending mode",     SortDirection.ASCENDING));
            actions.add(new SortDirectionAction(object, "Sort in descending mode",    SortDirection.DESCENDING));
          }
        
        @Override @Nonnull
        public Action getPreferredAction() 
          throws NotFoundException
          {
            throw new NotFoundException();
          }

        @Override @Nonnull
        public Collection<? extends Action> getActions() 
          {
            return new CopyOnWriteArrayList<Action>(actions); // don't expose internal status
          }
      };

    @Override @Nonnull
    public Node decorate (final @Nonnull Node node)
      {
        return new LookupFilterDecoratorNode(node, new LookupFilter()
          {
            @Override @Nonnull
            public Lookup filter (final @Nonnull Lookup lookup) 
              {
                return createLookupWith(lookup, new SortActionProvider(lookup));
              }
          });
      }
  }
